# Melee-YouTube-Uploader
A YouTube Uploader for my Melee recordings

A modified version of FRC-YouTube-Uploader for Super Smash Bros. Melee.

## To Do
* Automate creation of thumbnails
* Automate file picking
* Clean up the interface
* Update this README even more


## Contributing
PRs are appreciated and will be reviewed quickly, the only code quality standard I have is to follow PEP8 standard except for the line length. If you have trouble understanding my code just ask me.

## Current Feature Set:
* Upload videos
* Queue and dequeue Videos to upload
* Adds a lot of relevant tags
* Adds to a YouTube playlist
* Saves and loads form values
* Loading values from history

## How to Setup
1. Install [Python 3.7.1](https://www.python.org/downloads/release/python-371/) for your OS with the PATH added and make sure there are no other versions of Python 3.
2. Install the program with `pip3 install -U meleeuploader`. If you want untested features you can download the repo and install with `pip3 install -U /path/to/repo`
3. Start the program by running `meleeuploader` in terminal.
4. Add in the necessary info in the Event Values and Match Values tabs
5. Hit submit every time a match finishes.
6. Update forms with the next match's info.
7. Enjoy not having to deal with YouTube's front end 🎉.
